#include "Game.h"

volatile int Game::tick = 0;

void Game::timer()
{
    tick++;
}
END_OF_FUNCTION(Game::Timer);

Game::Game()
{
    buffer = NULL;

    game_step = PRESENTS;
}

Game::~Game()
{
    if(buffer)
    {
        destroy_bitmap(buffer);

        buffer = NULL;
    }
}

void Game::setup()
{
    int gfx, depth;

    int w, h;

    allegro_init();

    set_config_file("bomberman.cfg");

    if(ustrcmp(get_config_string("gfx","windowed","yes"), "yes") == 0)
        gfx = GFX_AUTODETECT_WINDOWED;

    else
        gfx = GFX_AUTODETECT_FULLSCREEN;

    depth = get_config_int("gfx", "depth", 32);

    w = get_config_int("gfx", "width", 640);

    h = get_config_int("gfx", "height", 480);

    set_color_depth(depth);

    if(set_gfx_mode(gfx, w, h, 0, 0) < 0)
    {
        allegro_message(allegro_error);

        exit(1);
    }

    set_window_title(get_config_string(NULL, "title", "Bomberman Project"));

    set_display_switch_mode(SWITCH_BACKGROUND);

    set_uformat(U_ASCII);

    install_keyboard();
    install_timer();

    LOCK_VARIABLE(tick);

    LOCK_FUNCTION(Game::timer);

    install_int_ex(Game::timer, BPS_TO_TIMER(14));

    buffer = create_bitmap(w, h);
}

void Game::run(GameStep* step)
{
    step->load();

    while(!step->quit())
    {
        step->input();

        while(tick > 0)
        {
            step->process();

            tick--;
        }

        step->draw(buffer);
    }

    step->unload();
}

void Game::mainLoop()
{
    while(game_step != EXIT)
    {
        switch(game_step)
        {
            case PRESENTS :

                run(new PresentsStep(&game_step));

                break;

            case MAINMENU :

                run(new MainMenuStep(&game_step));

                break;

            case SINGLEPLAYER :

                run(new BattleStep(&game_step));

                break;

            case OPTIONS :

                run(new OptionsStep(&game_step));

                break;

            case CREDITS :

                run(new CreditsStep(&game_step));

                break;
        };
    }
}
