#include "Menu.h"

Menu::Menu(string _title, int _x, int _y)
: title(_title), x(_x), y(_y)
{
    selected_item = -1;
}

Menu::~Menu()
{
}

void Menu::add(string _text, ItemState _state)
{
    MenuItem item = {_text, _state, false};

    if(_state == ENABLED)
    {
        if(items.empty())
        {
            selected_item = 0;

            item.selected = true;
        }

        else if(selected_item == -1)
        {
            selected_item = items.size();

            item.selected = true;
        }
    }

    items.push_back(item);
}

void Menu::remove(string _text)
{
    for(unsigned int i = 0; i < items.size(); i++)
        if(items[i].text == _text)
        {
            items.erase(items.begin() + i);

            if(selected_item == i)
                selected_item = items.empty() ? -1 : 0;
        }
}

void Menu::removeAll()
{
    items.clear();

    selected_item = -1;
}

void Menu::previous()
{
    items[selected_item].selected = false;

    do
    {
        selected_item--;

        if(selected_item< 0)
            selected_item = items.size() -1;
    }
    while(items[selected_item].state == DISABLED);

    items[selected_item].selected = true;
}

void Menu::next()
{
    items[selected_item].selected = false;

    do
    {
        selected_item++;

        if(selected_item >= items.size())
            selected_item = 0;
    }
    while(items[selected_item].state == DISABLED);

    items[selected_item].selected = true;
}

void Menu::draw(BITMAP* buffer)
{
    textout_ex(buffer, font, title.c_str(), x, y, WHITE, NO_BGCOLOR);

    for(unsigned int i = 0; i < items.size(); i++)
    {
        int color = WHITE;

        int bg_color = NO_BGCOLOR;

        if(items[i].state == DISABLED)
            color = GRAY;

        if(items[i].selected)
        {
            color = YELLOW;

            bg_color = RED;
        }

        textout_ex(buffer, font, items[i].text.c_str(), x, y + (i + 1) * 10, color, bg_color);
    }
}

int Menu::getSelected()
{
    return selected_item;
}
