#include "Player.h"

Player::Player(int _x, int _y)
: ArenaElement(_x, _y)
{
    counter = 0;

    state = STAND;

    dir = SOUTH;

    for(int i = 0; i < 4; i++)
    {
        front[i] = create_bitmap(34, 48);
        back[i]  = create_bitmap(34, 48);
        left[i]  = create_bitmap(40, 48);
        right[i] = create_bitmap(40, 48);
    }
}

Player::~Player()
{
    for(int i = 0; i < 4; i++)
    {
        if(front[i])
        {
            destroy_bitmap(front[i]);
            front[i] = NULL;
        }

        if(back[i])
        {
            destroy_bitmap(back[i]);
            back[i] = NULL;
        }

        if(left[i])
        {
            destroy_bitmap(left[i]);
            left[i] = NULL;
        }

        if(right[i])
        {
            destroy_bitmap(right[i]);
            right[i] = NULL;
        }
    }

    if(current)
    {
        delete current;
        current = NULL;
    }

}

void Player::load(const char* filename)
{
    DATAFILE* sprites = load_datafile(filename);

    if(!sprites)
    {
        allegro_message("No foi possvel encontrar o arquivo %s.", filename);

        exit(1);
    }

    stretch_blit((BITMAP*)sprites[0].dat, front[0], 0,0, 17,24, 0,0, 34,48);
    stretch_blit((BITMAP*)sprites[1].dat, front[1], 0,0, 17,24, 0,0, 34,48);
    stretch_blit((BITMAP*)sprites[0].dat, front[2], 0,0, 17,24, 0,0, 34,48);
    stretch_blit((BITMAP*)sprites[2].dat, front[3], 0,0, 17,24, 0,0, 34,48);

    stretch_blit((BITMAP*)sprites[3].dat, back[0], 0,0, 17,24, 0,0, 34,48);
    stretch_blit((BITMAP*)sprites[4].dat, back[1], 0,0, 17,24, 0,0, 34,48);
    stretch_blit((BITMAP*)sprites[3].dat, back[2], 0,0, 17,24, 0,0, 34,48);
    stretch_blit((BITMAP*)sprites[5].dat, back[3], 0,0, 17,24, 0,0, 34,48);

    stretch_blit((BITMAP*)sprites[6].dat, left[0], 0,0, 20,24, 0,0, 40,48);
    stretch_blit((BITMAP*)sprites[7].dat, left[1], 0,0, 20,24, 0,0, 40,48);
    stretch_blit((BITMAP*)sprites[6].dat, left[2], 0,0, 20,24, 0,0, 40,48);
    stretch_blit((BITMAP*)sprites[8].dat, left[3], 0,0, 20,24, 0,0, 40,48);

    stretch_blit((BITMAP*)sprites[ 9].dat, right[0], 0,0, 20,24, 0,0, 40,48);
    stretch_blit((BITMAP*)sprites[10].dat, right[1], 0,0, 20,24, 0,0, 40,48);
    stretch_blit((BITMAP*)sprites[ 9].dat, right[2], 0,0, 20,24, 0,0, 40,48);
    stretch_blit((BITMAP*)sprites[11].dat, right[3], 0,0, 20,24, 0,0, 40,48);

    unload_datafile(sprites);

    current = front[0];
}

void Player::draw(BITMAP* buffer)
{
    draw_sprite(buffer, current, x - (current->w - TILE_W)/2, y - (current->h - TILE_H)/2);
    //stretch_sprite(buffer, current, x, y, 40, 40);

    rect(buffer, x + (40 - current->w)/2, y , x + (40 - current->w)/2 + current->w, y + 40, BLUE);
    rect(buffer, x, y, x + 40, y + 40, YELLOW);

    textprintf_ex(buffer, font, 50, 50, GREEN, NO_BGCOLOR, "x=%d,y=%d", x, y);
}

void Player::process()
{
    if(state == WALKING)
    {
        counter++;

        if(counter > 3) counter = 0;

        switch(dir)
        {
            case NORTH :
                y -= WALK_STEP;
                current = back[counter];
                break;
            case SOUTH :
                y += WALK_STEP;
                current = front[counter];
                break;
            case WEST :
                x -= WALK_STEP;
                current = left[counter];
                break;
            case EAST :
                x += WALK_STEP;
                current = right[counter];
                break;
        }
    }

    else
    {
        counter = 0;

        switch(dir)
        {
            case NORTH :
                current = back[0];
                break;
            case SOUTH :
                current = front[0];
                break;
            case WEST :
                current = left[0];
                break;
            case EAST :
                current = right[0];
                break;
        }
    }
}

void Player::setDirection(Direction d)
{
    dir = d;
}

void Player::walk()
{
    state = WALKING;
}

void Player::stop()
{
    state = STAND;
}

int Player::width()
{
    return current->w;
}

int Player::height()
{
    return current->h;
}
